Language

Enum Language 

pub enum Language {
Show 13 variants English, Dutch, French, German, Italian, Polish, Romanian, Russian, Spanish, Swedish, Turkish, Ukrainian, TokiPona,
}

Variants



English

en 🇬🇧 💂



Dutch

nl 🇳🇱 🧀



French

fr 🇫🇷 🥐



German

de 🇩🇪 🥨



Italian

it 🇮🇹 🍕



Polish

pl 🇵🇱 🥟



Romanian

ro 🇷🇴 🧛



Russian

ru 🇷🇺 🪆



Spanish

es 🇪🇸 🐂



Swedish

sv 🇸🇪 ❄️



Turkish

tr 🇹🇷 🕌



Ukrainian

uk 🇺🇦 ✊



TokiPona

tp 🇨🇦 🙂

Implementations

Source

impl Language

pub fn from_code(b: [u8; 2]) -> Option<Self>

pub fn code_array(self) -> [u8; 2]

pub fn code_str(self) -> &'static str

pub fn name_english(self) -> &'static str

The language name in English.

pub fn name_native(self) -> &'static str

The language name in the language itself (endonym).

pub fn encoding(self) -> &'static str

ISO 8859 encoding slug for the language.

Useful for dynamically loading the correct font for the given language.