get_settings

Function get_settings 

pub fn get_settings<P: AnyPeer>(p: P) -> Settings
Get the peer’s system settings.

IMPORTANT: This is the only function that accepts as input not only Peer but also Me, which might lead to a state drift if used incorrectly. See the docs for more info.