load_stash_buf

Function load_stash_buf 

pub fn load_stash_buf<const N: usize>(peer: Peer) -> Option<[u8; N]>
Similar to load_stash but statically allocates the stash of the right size.

Unlike load_stash, the returned stash size is not adjusted for the actual content size.

Unlike other _buf functions, like load_file_buf, this one allocates the buffer statically, not dynamically. The app must statically know the max stash size.