draw_nine_slice

Function draw_nine_slice 

pub fn draw_nine_slice(i: &SubImage<'_>, p: Point, s: Size)
Fill the given area with the given 9-slice.

A 9-slice is used to tile an area with 9 sub-images: 4 corners, 4 edges, and 1 middle segment. It is useful for speech bubbles and other stylish boxes.

The whole image is the 9-slice. The sub-image is the center area of the 9-slice.

If the target area is bigger than the 9-slice segments, all the segments (except corners) are repeated (“tiled”) without stretching or mirroring.