CanvasRef

Struct CanvasRef 

pub struct CanvasRef<'a> { /* private fields */ }
Canvas is an Image that can be drawn upon.

Implementations

Source

impl<'a> CanvasRef<'a>

pub fn new(s: Size, raw: &'a mut [u8]) -> Option<Self>

Create new empty canvas using the given slice.

Returns None if the slice is too small for the given image size. A bigger slice than needed is fine.

pub fn into_image(self) -> ImageRef<'a>