ImageRef

Struct ImageRef 

pub struct ImageRef<'a> { /* private fields */ }
A loaded image file.

Can be loaded as FileRef from ROM with load_file and then cast using Into.

Implementations

Source

impl<'a> ImageRef<'a>

pub unsafe fn from_bytes(raw: &'a [u8]) -> Self

Reinterpret raw bytes as an image.

Safety

Using this function requires a good understanding of the internal Firefly Zero binary image format. In 99% cases, you should not construct a raw image but instead load it from a [File] or generate using Canvas.