Me

Struct Me 

pub struct Me(/* private fields */);
The peer representing the current device.

Can be compared to Peer or used to get_settings.

IMPORTANT: Using this type may cause state drift between device in multiplayer. See the docs for more info.