Settings

Struct Settings 

pub struct Settings {
    pub theme: Theme,
    pub language: Language,
    pub rotate_screen: bool,
    pub reduce_flashing: bool,
    pub contrast: bool,
    pub easter_eggs: bool,
}
System settings. Can be requested using get_settings.

Fields

theme: Theme

The preferred color scheme of the player.

language: Language

The configured interface language.

rotate_screen: bool

If true, the screen is rotated 180 degrees.

In other words, the player holds the device upside-down. The touchpad is now on the right and the buttons are on the left.

reduce_flashing: bool

The player has photosensitivity. The app should avoid any rapid flashes.

contrast: bool

The player wants increased contrast for colors.

If set, the black and white colors in the default palette are adjusted automatically. All other colors in the default palette or all colors in a custom palette should be adjusted by the app.

easter_eggs: bool

If true, the player wants to see easter eggs, holiday effects, and weird jokes.