pub struct Theme {
pub id: u8,
pub primary: Color,
pub secondary: Color,
pub accent: Color,
pub bg: Color,
}Expand description
The preferred color scheme of the peer.
Can be useful for:
- Making UI that matches the system UI.
- Preventing image flashes by making the UI background the same as in the system UI.
- Providing and auto-switching the dark and light mode.
Fields
id: u8primary: ColorThe main color of text and boxes.
secondary: ColorThe color of disable options, muted text, etc.
accent: ColorThe color of important elements, active options, etc.
bg: ColorThe background color, the most contrast color to primary.