firefly_rust::graphics

Struct CanvasBuf

pub struct CanvasBuf { /* private fields */ }
Canvas is an Image that can be drawn upon.

CanvasBuf is the same as Canvas but holds the ownership of the underlying slice.

Implementations

Source

impl CanvasBuf

pub fn new(s: Size) -> Self

Create new empty canvas.

pub const fn as_image(&self) -> Image<'_>

Represent the canvas as an Image.

pub const fn as_canvas(&self) -> Canvas<'_>

Represent the buffered canvas as Canvas.