macro_rules! log_debug {
() => { ... };
($f: literal) => { ... };
($f: expr) => { ... };
($f: literal, $( $a:expr ),* ) => { ... };
}Expand description
A convenience macro for debug logging using [log_debug] function.
- When called without arguments, will print the current file name and line number.
- When called with a string, just prints that string.
- When called with multiple arguments, prints a string produced by [
format!].